Bee – Minecraft Wiki
Description: Java Edition

# Bee

From Minecraft Wiki
Jump to navigation Jump to search
For other uses, see Bee (disambiguation).
Bee

Java Edition

Bedrock Edition

Java Edition

Bedrock Edition

Java Edition

Bedrock Edition

Java Edition

Bedrock Edition

Health points | 10HP
Behavior | Neutral
Mob type | Animal Arthropod
Attack strength | Melee: Easy: 2HP Normal: 2HP Hard: 3HP Venom: Normal: Poison I for 10 sec (HP) Hard: Poison I for 18 sec (HP × 7)
Hitbox size | In Java Edition: Adult: Height: 0.6 blocks Width: 0.7 blocks Baby: Height: 0.3 blocks Width: 0.35 blocks In Bedrock Edition: Adult: Height: 0.5 blocks Width: 0.55 blocks Baby: Height: 0.25 blocks Width: 0.275 blocks
Speed | 0.6
Spawn | Naturally generated Bee Nests
Usable items | Flower Mangrove Propagule Flowering Azalea Flowering Azalea Leaves Cherry Leaves Pink Petals Wildflowers Spore Blossom Cactus Flower Chorus Flower Lead

    {
        "title": "Bee",
        "rows": [
            {
                "field": "10<span class=\"hidden-alt-text\">HP</span><span class=\"nowrap mc-hearts\"><span class=\"iconbar pixel-image nowrap\" style=\"--icon-offset:-1px;\" title=\"5  hearts\">(link to File:Heart (icon).png article, displayed as 9px|link=|alt=❤️)(link to File:Heart (icon).png article, displayed as 9px|link=|alt=❤️)(link to File:Heart (icon).png article, displayed as 9px|link=|alt=❤️)(link to File:Heart (icon).png article, displayed as 9px|link=|alt=❤️)(link to File:Heart (icon).png article, displayed as 9px|link=|alt=❤️)</span></span>",
                "label": "(link to Health article, displayed as Health points)"
            },
            {
                "field": "Neutral",
                "label": "Behavior"
            },
            {
                "field": "<span class=\"nowrap\"><span class=\"sprite-file\" style=\"\">(link to File:EntitySprite animal.png article, displayed as 16x16px|link=Animal|alt=|class=pixel-image|)</span>(link to Animal article, displayed as <span class=\"sprite-text\">Animal</span>)</span><br><span class=\"nowrap\"><span class=\"sprite-file\" style=\"\">(link to File:EntitySprite arthropod.png article, displayed as 16x16px|link=Arthropod|alt=|class=pixel-image|)</span>(link to Arthropod article, displayed as <span class=\"sprite-text\">Arthropod</span>)</span>",
                "label": "(link to Mob type article, displayed as Mob type)"
            },
            {
                "field": "(values exceeds 1000 characters...)",
                "label": "Attack<br/>strength"
            },
            {
                "field": "'''In (link to Java Edition article, displayed as ''Java Edition''):'''<br>\n'''Adult:'''<br>Height: 0.6 blocks<br>Width: 0.7 blocks<br>\n'''Baby:'''<br>Height: 0.3 blocks<br>Width: 0.35 blocks<br>\n'''In (link to Bedrock Edition article, displayed as ''Bedrock Edition''):'''<br>\n'''Adult:'''<br>Height: 0.5 blocks<br>Width: 0.55 blocks<br>\n'''Baby:'''<br>Height: 0.25 blocks<br>Width: 0.275 blocks",
                "label": "(link to Hitbox article, displayed as Hitbox size)"
            },
            {
                "field": "0.6",
                "label": "(link to Attribute#Movement_speed article, displayed as Speed)"
            },
            {
                "field": "Naturally generated <span class=\"nowrap\"><span class=\"sprite-file\" style=\"\">(link to File:BlockSprite bee-nest.png article, displayed as 16x16px|link=Bee Nest|alt=|class=pixel-image|)</span>(link to Bee Nest article, displayed as <span class=\"sprite-text\">Bee Nests</span>)</span>",
                "label": "(link to Mob spawning article, displayed as Spawn)"
            },
            {
                "field": "(values exceeds 1000 characters...)",
                "label": "Usable items"
            }
        ],
        "invimages": [
            "Bee Spawn Egg"
        ],
        "images": [
            "Bee.gif",
            "Bee BE.gif",
            "Bee with nectar.gif",
            "Bee with nectar BE.gif",
            "Bee (angry).gif",
            "Bee (angry) BE.gif",
            "Bee with nectar (angry).gif",
            "Bee with nectar (angry) BE.gif"
        ]
    }

A bee is a flying arthropodan neutral mob that lives in a bee nest or beehive, and fills it with harvestable honey using nectar it gathers from flowers. Attacking a bee, or interfering with its home without proper precautions, causes it and all nearby bees to attack using their stingers. If a bee attacks something, it will lose its stinger and eventually die.

## Spawning[edit | edit source]

Bees are the only arthropod mob that can spawn in any difficulty including Peaceful.

### Natural generation[edit | edit source]

Naturally generated bee nests generate with 3 bees in them.

Naturally-generated birch or oak trees have equal chances to generate with a bee nest, depending on the biome:

Biome | Chance
--- | ---
JE | BE
Meadow | 100%
Plains Sunflower plains | 5%
Mangrove Swamp | 5% | 4%
Flower forest | 2% | 3%
Forest Birch forest Old growth birch forest | 0.2% | 0.035%
Cherry Grove | 5% | ?%

### Saplings[edit | edit source]

Birch, cherry, and oak trees grown from saplings that are within 2 blocks of any 1- or 2-block tall flowers, flowering azalea, cherry leaves, flowering azalea leaves, mangrove propagule, spore blossom, pink petals, or chorus flower have a 5% chance of having a bee nest containing 2–3 bees.

Mangroves grown from mangrove propagules have a 1% chance of having a bee nest containing 2-3 bees. Unlike birch, cherry and oak trees, no flowers are required for a bee nest to generate.[1]

## Drops[edit | edit source]

### On death[edit | edit source]

Upon death, adult bees drop 1–3XP experience when killed by a player or a tamed wolf. Like other baby animals, killing a baby bee yields no experience.

### Breeding[edit | edit source]

Upon breeding with any flower successfully, 1–7XP is dropped.

## Behavior[edit | edit source]

Bees do not fly (like ghasts or the ender dragon), but instead hover a few blocks above the ground similar to bats and parrots.

Bees are considered arthropods and take increased damage from the Bane of Arthropods enchantment.[2] They also take damage when touching water.[3]

Bees can be attached to a lead, even when angered. They can still attack while attached.

Bees usually venture up to 22 blocks from their beehive to collect nectar from a viable plant or to attack someone. Bees can venture farther away if necessary.

Bees do not take damage from sweet berry bushes.

A bee can fly horizontally and vertically upward through scaffolding but does not fly downward. A bee does not fly through an open trapdoor or regular door on its own (a bee can be led through a door with a flower) but babies can fly through the gap above a fence gate in a 1×2 doorway.

Despite being flying mobs, bees can destroy turtle eggs when on top of them.[4]

### Pollinating[edit | edit source]

Bees leave their nest during the day. They fly around their nests and are attracted to flowers (except closed eyeblossoms), flowering azaleas, flowering azalea leaves, mangrove propagules, pink petals, cherry leaves, spore blossoms, chorus flowers, cactus flowers, and wildflowers, which are the valid plants for the bee to gather nectar from. Bees can gather nectar from wither roses but receive the wither effect. As a result, bees can die.[5] Bees can also gather nectar from open eyeblossoms, but get poisoned as result; they completely ignore closed eyeblossoms and are unable to gather nectar from them. Bees also completely ignore flowers in flower pots.[6][7]

After circling a flower for more than 400 ticks, a bee collects nectar. However, if the bee gets damaged, it ceases its efforts to collect nectar. A bee carrying nectar has nectar spots on its abdomen and drops nectar particles to fertilize plants below the bee.

Bees that have nectar may pollinate wheat crops, potato crops, carrot crops, beetroot crops, melon stems, sweet berry bushes, pumpkin stems, cave vines, torchflower crops, and pitcher crops‌[Bedrock Edition only] that they fly over. When one of these plants gets pollinated, it advances to another growth stage, similar to using bone meal. To pollinate a plant, a bee must be 1 to 2 blocks directly above the plant and must have a valid home hive. A bee can fertilize plants 10 times each time they have nectar. There is an approximately 5% chance each tick to attempt fertilization.

Afterward, the bee flies back into its hive/nest to make honey. It takes about 2 minutes for the bee to do this.

### Housing[edit | edit source]

A bee going into a bee nest.
See also: Tutorial:Honey farming

Bees live together in colonies and take any bee nest or beehive that has enough space as its home. One bee nest/beehive can house up to 3 bees. Homeless bees search for empty beehives by wandering around generally in a northwest direction. Bees can enter a beehive from any side, but exit only from the front. One-way bee-gates can be made by using this mechanic.

Bees return to their nest when it rains and during the night. This behavior extends to biomes that don't rain, such as the desert. They stay in their nest or hive for at least 2400 game ticks (2 minutes) before coming back out. Bees in a nest/hive retain their data (health, name, etc.).

Breaking a nest or hive without Silk Touch releases all bees contained inside. If the nest or hive is harvested using a tool enchanted with Silk Touch, the bees are contained in the dropped item and can exit the nest/hive when it is placed again.

When a bee that has nectar enters and then leaves its nest or hive, the honey level of the nest/hive is increased by one; there is a 1% chance it is increased by two. When the honey level of that hive reaches 5, the player can harvest honeycombs or honey bottles. The honey level resets back to 0 when a honeycomb or honey bottle is harvested.

Because there is neither daylight cycle nor weather in the Nether and the End, bees work without resting in these dimensions. This behavior is distinct from that of the villagers, which follow their daily routine according to the time in the Overworld, regardless of which dimension they are in.

### Attacking[edit | edit source]

Main article: Damage

All bees nearby are angered when an individual bee is attacked (unless the bee attacked is killed in one hit), honey or honeycombs are collected (unless a campfire is placed under the nest), or a bee nest/beehive is destroyed. Even destroying newly-placed uninhabited beehives anger nearby bees. Hitting or walking on a beehive does not anger bees; only destroying it angers them. When destroyed, a beehive releases any bees that it contained. If the beehive is destroyed with a Silk Touch tool, bees kept within the hive remain neutral, while those outside the hive also remain neutral.

The Invisibility effect does not cause stingers in stung players to disappear.

Bees attack and swarm the player as a group when angered, and the eyes of angered bees turn red. Collecting a honeycomb or a honey bottle from a nest or hive causes the bees that are currently in that nest or hive to leave and swarm the player unless a campfire is placed below the hive. Bees attack only once, similar to llamas, and non-aggressive pandas.

Bees do not deal any damage in Peaceful difficulty and are completely passive. They fly outside the beehive and search for flowers as usual.

If the player deflects a bee's attack with a shield, the bee continues attacking until it succeeds in hitting the player.

When a bee's attack on a player succeeds, the player is poisoned. A bee loses its stinger after a successful attack, cannot attack further and does not retreat to its nest (even at night), and dies approximately one minute later. This can be delayed with potion effects (Regeneration/Resistance/Absorption) that have a 255 potency.

It is possible to (quickly) breed at least one angered bee with another, even if it or they had stung and lost the stinger. However, they remain angered and still die later due to being stingerless.

Bees also swarm and attack other mobs when damaged, for example, if a skeleton accidentally shoots a bee.

Bees become neutral if they fail to land a hit on their target for a certain amount of time.[check the code]

- The stinging animation; the bee can remain upside down for longer periods of time if a distance is kept.
- Prior to stinging
- After stinging

In Java Edition, a bee's stinger is visible on the player as a small black dot after the bee successfully attacked.

### Breeding[edit | edit source]

Main article: Breeding

Bees follow players holding any 1- or 2-block tall flowers (except closed eyeblossom), mangrove propagules, flowering azaleas, flowering azalea leaves, cherry leaves, pink petals, wildflowers, spore blossoms, cactus flowers or chorus flowers. If the player is standing still and being followed by bees, the bees go toward the player, face the player, and rest on the ground. They do this until the player moves.

If bees are given any of the blocks listed above (except open eyeblossom and wither rose), they enter love mode and pair up to create baby bees, granting the player 1-7 experience. The parent bees have a cooldown of 5 minutes (6000 ticks) before they can be bred again. Babies take 20 minutes (1 in-game day) to grow up. The growth of baby bees can be accelerated using flowers; each use reduces the remaining time by 10%. However, bees' growth timer and breeding cooldowns are frozen while working in a hive; thus, when rapidly growing a population, it may be desirable to temporarily remove the hives.

Wither roses and open eyeblossoms cannot be used for breeding bees or growing baby bees. Feeding a bee a wither rose inflicts it with the Wither effect for 2 seconds (40 game ticks), while feeding a bee an open eyeblossom inflicts it with Poison for 1.25 seconds (25 game ticks). Closed eyeblossoms cannot be used to lead, breed or grow bees.

## Sounds[edit | edit source]

Java Edition:

Sounds
Sound | Closed captions | Source | Description | Identifier | Translation key | Volume | Pitch | Attenuation distance
--- | --- | --- | --- | --- | --- | --- | --- | ---
| ​Bee buzzes | Friendly Mobs | While a bee is passive and moving horizontally | `entity.bee.loop` | `subtitles.entity.bee.loop`​ | varies [sound 1] [sound 2] | 0.98-1.14 (Baby: 1.54-1.7) [sound 3] | 6
| ​Bee buzzes angrily | Friendly Mobs | While a bee is hostile and moving horizontally | `entity.bee.loop_aggressive` | `subtitles.entity.bee.loop_aggressive`​ | 0.8 [sound 2] | 0.98-1.14 (Baby: 1.54-1.7) [sound 3] | 10
| ​Bee stings | Friendly Mobs | When a bee stings something | `entity.bee.sting` | `subtitles.entity.bee.sting`​ | 1.0 | 1.0/0.8 | 16
| ​Bee dies | Friendly Mobs | When a bee dies | `entity.bee.death` | `subtitles.entity.bee.death`​ | 0.4 | 0.8-1.2 (Baby: 1.3-1.7) | 16
| ​Bee hurts | Friendly Mobs | When a bee is damaged | `entity.bee.hurt` | `subtitles.entity.bee.hurt`​ | 0.4 | 0.8-1.2 (Baby: 1.3-1.7) [sound 4] | 16
| ​Bee buzzes happily | Friendly Mobs | While a bee is collecting pollen | `entity.bee.pollinate` | `subtitles.entity.bee.pollinate`​ | 0.8 | 1.0 | 12

1. ↑ `loop1` and `2` are multiplied by 0.6; `loop3` and `4` are 0.65; `loop5` is 0.7 and 0.75
2. ↑ a b Multiplied by the bee's horizontal velocity (capped at 0.5) × 1.2
3. ↑ a b The bee's horizontal velocity (capped between 0.7-1.1 (Baby: 1.1-1.5)), linearly interpolated between 0.7 and 1.1 (Baby: 1.1 and 1.5)
4. ↑ Can be multiplied by 1.0 or 1.2 for each sound

Bedrock Edition:

Sounds
Sound | Closed captions [upcoming: BE 26.0] | Source | Description | Identifier | Translation key [upcoming: BE 26.0] | Volume | Pitch
--- | --- | --- | --- | --- | --- | --- | ---
| ​ ? | Friendly Mobs | When a bee dies | `mob.bee.death` | ​ ? | 0.6 | 0.9-1.1 (Baby: 1.4-1.6)
| ​ ? | Friendly Mobs | When a bee is damaged | `mob.bee.hurt` | ​ ? | 0.6 | 0.9-1.1 (Baby: 1.4-1.6)
| ​ ? | Friendly Mobs | While a bee is passive and moving horizontally | `mob.bee.loop` | ​ ? | 0.6 | 1.0 (Baby: 1.5)
| ​ ? | Friendly Mobs | While a bee is hostile and moving horizontally | `mob.bee.aggressive` | ​ ? | 0.6 | 1.0 (Baby: 1.5)
| ​ ? | Friendly Mobs | While a bee is collecting pollen | `mob.bee.pollinate` | ​ ? | 0.85 | 1.0 (Baby: 1.5)
| ​ ? | Friendly Mobs | When a bee stings something | `mob.bee.sting` | ​ ? | 0.6 | 0.8-1.0 (Baby: 1.3-1.5)

## Data values[edit | edit source]

### ID[edit | edit source]

Java Edition:

Name | Identifier | Entity tags | Translation key
--- | --- | --- | ---
Bee | `bee` | `arthropod` `beehive_inhabitors` `fall_damage_immune` `followable_friendly_mobs` `sensitive_to_bane_of_arthropods` | `entity.minecraft.bee`

Bedrock Edition:

Name | Identifier | Numeric ID | Family | Translation key
--- | --- | --- | --- | ---
Bee | `bee` | `122` | `arthropod` `bee` `mob` `pacified` | `entity.bee.name`

### Entity data[edit | edit source]

Bees have entity data associated with them that contains various properties.

Java Edition:

Main article: Entity format

- [NBT Compound / JSON Object] Entity data
  - Additional fields for mobs that can become angry see Template:Nbt inherit/angerable/template
  - Additional fields for mobs that can breed see Template:Nbt inherit/breedable/template
  - Tags common to all entities see Template:Nbt inherit/entity/template
  - Tags common to all mobs see Template:Nbt inherit/mob/template
  - [Int] CannotEnterHiveTicks: Time left in ticks until the bee can enter a beehive. Used when the bee is angered and released from the hive by a player, but the hive is smoked by a campfire.
  - [Int] CropsGrownSincePollination: How many crops the bee has grown since its last pollination. Used to limit number of crops it can grow.
  - [Int Array] flower_pos: Block location, as 3 integers, of the flower that the bee is circling.
  - [Boolean] HasNectar: 1 or 0 (true/false) - true if the bee is carrying nectar.
  - [Boolean] HasStung: 1 or 0 (true/false) - true if the bee has stung a mob or player.
  - [Int Array] hive_pos: Block location, as 3 integers, of the bee's hive.
  - [Int] TicksSincePollination: Number of ticks passed since the bee's last pollination.

Bedrock Edition:

  See Bedrock Edition level format/Entity format.

## Achievements[edit | edit source]

Icon | Achievement | In-game description | Actual requirements (if different) | Gamerscore earned | Trophy type (PS)
--- | --- | --- | --- | --- | ---
PS4 | Other
|  | Bee our guest | Use a Campfire to collect Honey from a Beehive using a Bottle without aggravating the bees. | — | 15 | Bronze
|  | Total Beelocation | Move and place a Bee Nest, with 3 bees inside, using Silk Touch. | — | 30 | Silver
|  | It Spreads | Kill a mob next to a catalyst | Kill any mob that drops experience near a sculk catalyst, with the sole exception of the ender dragon. Mobs that drop no experience are ignored for this achievement. | 10 | Bronze

Achievements that apply to all mobs:

Icon | Achievement | In-game description | Actual requirements (if different) | Gamerscore earned | Trophy type (PS)
--- | --- | --- | --- | --- | ---
PS4 | Other
|  | Overkill | Deal nine hearts of damage in a single hit. | Damage can be dealt to any mob, even those that do not have nine hearts of health overall. | 30 | Bronze
|  | Over-Overkill | Deal 50 hearts of damage in a single hit using the Mace | Damage can be dealt to any mob, even those that do not have 50 hearts of health overall. | 20 | Silver
|  | Mob Kabob | Hit five mobs in the same Charge attack using the Spear. | Armor stands and players also count for this achievement as they are technically mobs. | 10 | Bronze

## Advancements[edit | edit source]

Icon | Advancement | In-game description | Actual requirements (if different)
--- | --- | --- | ---
| It Spreads | Kill a mob near a Sculk Catalyst | Kill any mob that drops experience near a sculk catalyst, with the sole exception of the ender dragon. Mobs that drop no experience are ignored for this advancement.
| Bee Our Guest | Use a Campfire to collect Honey from a Beehive using a Glass Bottle without aggravating the Bees | Use a glass bottle on a beehive or bee nest while not angering the bees inside.
| The Parrots and the Bats | Breed two animals together | Breed a pair of any of these 27 animals: Armadillo Axolotl Bee Camel Cat Chicken Cow Donkey Fox Frog Goat Hoglin Horse Llama Mooshroom Mule Nautilus Ocelot Panda Pig Rabbit Sheep Sniffer Strider Trader Llama Turtle Wolf A mule must be the result of breeding a horse and a donkey for this advancement as they are not breedable together. Other breedable mobs are ignored for this advancement.
| Total Beelocation | Move a Bee Nest, with 3 Bees inside, using Silk Touch | Unlike most other advancements, this advancement is granted upon breaking the nest, rather than it entering your inventory.
| Two by Two | Breed all the animals! | Breed a pair of each of these 26 animals: Armadillo Axolotl Bee Camel Cat Chicken Cow Donkey Fox Frog Goat Hoglin Horse Llama Mooshroom Mule Nautilus Ocelot Panda Pig Rabbit Sheep Sniffer Strider Turtle Wolf A trader llama does not count as a llama, and a mule must be the result of breeding a horse and a donkey for this advancement as they are not breedable together. Other breedable mobs can be bred, but are ignored for this advancement.

Advancements that apply to all mobs:

Icon | Advancement | In-game description | Actual requirements (if different)
--- | --- | --- | ---
| Adventure | Adventure, exploration and combat | Kill any mob, or be killed by any living entity.
| A Throwaway Joke | Throw a Trident at something. Note: Throwing away your only weapon is not a good idea. | Hit a mob with a thrown trident.
| Take Aim | Shoot something with an Arrow | Using a bow or a crossbow, shoot a mob with an arrow, tipped arrow, or spectral arrow.
| Mob Kabob | Hit five mobs in the same Charge attack using the Spear. | Armor Stand and Mannequin also count for this advancement.
| Arbalistic | Kill five unique mobs with one crossbow shot | Armor Stand and Mannequin also count for this advancement. This is a hidden advancement, meaning that it can be viewed by the player only after completing it, regardless of if its child advancement(s), if any, have been completed.
| Over-Overkill | Deal 50 hearts of damage in a single hit using the Mace | Damage can be dealt to any mob, even those that do not have 50 hearts of health overall.

## History[edit | edit source]

### Java Edition[edit | edit source]

Java Edition
1.15 | 19w34a | Added bees and baby bees.
19w35a | Bees now try to avoid water.
Bee nests now spawn less frequently, making bees rarer.
Breeding bees now counts toward the "Two by Two" advancement.
19w36a | Bees are now affected by the Bane of Arthropods enchantment.
Bees are now able to gather pollen from lilac, rose bush, and peony flowers.
The textures of bees have been tweaked. The gradation part for picking up the color has been removed and the translucent pixels are now fully transparent.[8]
`bee_angry_nectar` now has same nectar pattern as `bee_nectar`, which has changed the textures from to .[9]
Bees no longer stop flying after reaching the player they are following.
19w45a | Bees now search up to 10 blocks away from itself in all directions to find a nest/hive to claim.
19w46a | Bees now exit beehives only from the front.
1.15.2 | pre1 | Bees no longer anger when a nearby nest/hive is destroyed using a Silk Touch tool.
Bees now remember how many crops they have pollinated.
Bees no longer stay in the hive/nest forever after riding a minecart or boat.
1.16 | 20w10a | Firework damage now provokes bees.[10]
20w12a | The maximum distance a bee can wander away from its home hive when randomly wandering has been reduced to around 22 blocks.
1.17 | 21w13a | Bees now see flowering azalea and flowering azalea leaves as flowers.
1.19 | 22w11a | Bees now see mangrove propagule as flowers.[11]
1.19.4 Experiment Update 1.20 | pre1 | Bees now see cherry leaves, pink petals, and torchflowers as flowers.[12]
1.20.2 | 23w33a | Bees now see spore blossom and chorus flower as flowers.[13]
1.20.5 | 24w11a | Adjusted their flying behavior to keep them from overshooting their position when flying up and down.
1.21.2 | 24w33a | Bees now wander around randomly for less time after exiting a nest/hive.
If a bee has a known nest/hive, it travels less far from it, thus being less likely to get lost.
Significantly increased the amount of time a bee can take to return to a known nest/hive before it gives up trying to return home.
Bees are now a lot less likely to get stuck on corners or when they are close to a nest/hive they are trying to return to.
Bees are also now a lot less likely to try and pathfind to a flower they cannot reach.
1.21.4 | 24w44a | Bees now get the Wither effect when fed with wither roses, and the Poison effect when fed with eyeblossoms.
24w45a | Bees are no longer attracted to closed eyeblossoms.
Bees can no longer interact with closed eyeblossoms.
24w46a | Bees no longer get poisoned when they touch a closed eyeblossom.
Leashed bees no longer enter beehives or bee nests.
1.21.5 | 25w02a | Are now attracted to, and can be bred using wildflowers.
25w06a | Are now attracted to, and can be bred using cactus flowers.
1.21.9 | 25w34a | Bees no longer hide in their hive in the End when it is raining in the Overworld.

### Bedrock Edition[edit | edit source]

Bedrock Edition
1.14.0 | beta 1.14.0.1 | Added bees.
Bees and baby bees can become angry and attack the player.
Bees and baby bees can gather nectar from flowers, and show the nectar on them after doing so.
Bees and baby bees that have nectar can become angry and attack the player.
1.16.0 | beta 1.16.0.63 | Bees no longer fly faster when swarming a player or mob.
1.17.0 | beta 1.16.230.50 | Bees are now attracted to flowering azalea and flowering azalea leaves.
beta 1.17.0.56 | Bees no longer gather nectar from sweet berry bushes.
1.20.60 | Preview 1.20.60.25 | Bees no longer take damage when moving through sweet berry bushes.
1.21.50 | Preview 1.21.50.28 | Bees now get the Wither effect when fed with wither roses.
Bees can no longer be tempted or collect nectar from closed eyeblossoms.
Feeding bees open eyeblossoms now applies the poison effect.

### Data history[edit | edit source]

Java Edition
1.20.5 | 24w06a | Changed bee entity data: Changed [NBT Compound / JSON Object] FlowerPos (with [Int] x, [Int] y and [Int] z) to [Int Array] flower_pos. Changed [NBT Compound / JSON Object] HivePos (with [Int] x, [Int] y and [Int] z) to [Int Array] hive_pos.

## Issues[edit | edit source]

Issues relating to "Bee" are maintained on the bug tracker. Issues should be reported and viewed there.

## Trivia[edit | edit source]

- Bees were made to be half a block in size because Mojang considered this size to be the cutest.[14]
- Bees pollinate the top half of sunflowers.
- In reality, juvenile bees are helpless, worm-like larvae, not smaller versions of adults.
- Also in reality, bees collect both nectar and pollen by pollinating flowers. The pollen is used as a primary food source by the bee colony, but has little direct importance to the formation of honey, which is made from the nectar and serves as another food source. Also, in real life, bees are scared of smoke and don't exit the nest or hive.
- However, bees losing their stingers and dying after attacking the player is consistent with real bees, as in reality their stingers are barbed and attached to vital organs, so the stinger gets stuck and causes fatal injuries to the bee once it tries to fly away and the stinger detaches.

## Gallery[edit | edit source]

### Renders[edit | edit source]

#### Idle[edit | edit source]

- A bee.
- A bee with nectar on it.
- An angry bee.
- An angry bee with nectar on it.

#### Animations[edit | edit source]

- A bee flying in Java Edition.
- A bee in Bedrock Edition.
- A bee flying in Bedrock Edition.
- A bee stinging.
- A bee bobbing.

### Screenshots[edit | edit source]

- A naturally generated bee nest in a village in a Superflat world.
- A tree with a bee nest in the center of a player-made garden of crops.
- A bee gathering nectar.
- Bees attacking a llama.
- A bee in a forest.

### Mojang images[edit | edit source]

- Bees on leads.
- A bee.
- Bees in a flower forest.
- The inside of a bee.

### Concept artwork[edit | edit source]

- Old bee concept artwork and design iterations.
- An unreleased bee texture and model.
- A concept of a bee during development.
- An old bee design from Henrik Kniberg's video.
- Concept art for bee-themed items in the character creator.
- A recreation of one of the bees.
- Ditto.

### Textures[edit | edit source]

- Bee texture file.
- Bee nectar texture file.
- Angry bee texture file.
- Angry bee nectar texture file.
- Bee stinger texture file.

### In other media[edit | edit source]

- Artwork
- Artwork of a beehive on oak with bees around it.
- Bees in promotional artwork for the Buzzy Bees Update.
- A Bee in Caves & Cliffs: Part I update artwork.
- Bees in banner for Education Edition 1.14.31.
- Artwork of a bee pollinating a cornflower.
- Bees in one of the Minecraft backgrounds for Microsoft Teams
- Several bees as drawn on an NPC.
- Another bee-themed NPC.
- Officially licensed bee plush.
- Lego Minecraft minifigure
- "Craft Without Limits," an official T-Shirt design featuring a bee.
- "Bee Pocket," a shirt design similiar to Craft Without Limits, but with a pocket.
- "I ❤️Minecraft," an official hoodie design featuring two bees.
- A woman holding an officially licensed bee moodlight.
- Bee Friender, a skin featured in the Builders & Biomes skin pack.
- Secondary Bee Friender.
- Bee Jumper
- Bee Shirt!
- Plastic texture pack
- The potato bee from 24w14potato.
- Ari with several bees in the Buzzy Bees section of 15 Year Journey.
- Bee in A Minecraft Movie.
- A bee waving hello with its wings.
- A render of the bee waving hello
- Bee figure of Flippin' Figs
- Bee pixel art.
- Angry bee.
- A bee as it appears in the Minecraft Movie live event.
- A bee plush on a couch with a plushes of Steve, a creeper, and an axolotl in the background.

## See also[edit | edit source]

- Bee Nest
- Beehive
- Honey Bottle
- Honeycomb

## References[edit | edit source]

1. ↑ MC-249937 — Propagules grown without a flower nearby can generate bee nests in the mangrove tree — resolved as "Works As Intended".
2. ↑ "Minecraft Snapshot 19w36a" – Minecraft.net, July 3, 2019.
3. ↑ MC-167148 — Bees take damage upon contact with water — resolved as "Works As Intended".
4. ↑ MC-248332
5. ↑ MC-159396 — Bees target wither roses and die — resolved as "Works As Intended".
6. ↑ MC-168267
7. ↑ MCPE-109956
8. ↑ MC-159560
9. ↑ MC-159743
10. ↑ MC-111498 — Fireworks and water bottles damage don't make neutral mobs angry or hostile — resolved as "Fixed".
11. ↑ MC-249147 — Bees pollinate and follow players holding the mangrove propagule (sapling) — resolved as "Works As Intended".
12. ↑ MC-260051
13. ↑ MC-214126 — Bees don't pollinate themselves with spore blossoms or chorus flowers — resolved as "Fixed".
14. ↑ "MINECON Live 2019" – Minecraft on YouTube, September 28, 2019

## External links[edit | edit source]

- Bee article on Wikipedia
- Mob Menagerie: Bee — Minecraft.net on September 15, 2023

## Navigation[edit | edit source]

Retrieved from "https://minecraft.wiki/w/Bee?oldid=3391677"
Categories:

- Entities
- Neutral mobs
- Arthropod mobs
- Animal mobs
- Flying mobs

Hidden categories:

- Check the code
- Pages with sound tables
- Pages with Java sound tables
- Pages missing subtitles
- Pages missing subtitle key
- Pages with Bedrock sound tables